@@ -25,6 +25,36 @@ $parla = "NO";
 include("./controlla_pass.php");
 include("$percorso_cartella_dati/head.php");
 
+$giornata_ultima = "00";
+for ($num1 = "01" ; $num1 < 100 ; $num1++) {
+if (strlen($num1) == 1) $num1 = "0".$num1;
+$giornata_controlla = "giornata$num1";
+if (!@is_file("$percorso_cartella_dati/$giornata_controlla")) break;
+else $giornata_ultima = $num1;
+} # fine for $num1
+
+$gol = "";
+for($num1 = 1 ; $num1 <= $giornata_ultima ; $num1++) {
+$num_giornata_scontri = $num1;
+if (strlen($num1) == 1) $num_giornata_scontri = "0".$num1;
+$giornata_scontri = "giornata$num_giornata_scontri";
+$file_giornata = file("$percorso_cartella_dati/$giornata_scontri");
+$num_linee_file_giornata = count($file_giornata);
+for($num2 = 0 ; $num2 < $num_linee_file_giornata; $num2++) {
+$linea = togli_acapo($file_giornata[$num2]);
+if ($linea == "#@& fine scontri #@&") $leggendo_scontri = "NO";
+if ($leggendo_scontri == "SI") {
+unset($scontri);
+$scontri = explode("##@@&&",$linea);
+$gol[$num1][$scontri[0]] = $scontri[2];
+$gol[$num1][$scontri[1]] = $scontri[3];
+} # fine if ($leggendo_scontri == "SI")
+if ($linea == "#@& scontri #@&") {
+$leggendo_scontri = "SI";
+} # fine if ($linea == "#@& scontri #@&")
+} # fine for $num2
+} # fine for $num1
+
 
 $num_giocatori=count($pass);
 reset($pass);
@@ -97,7 +127,7 @@ if ($giornata_in_corso == "SI") {
 $partita = explode("-",$linea_file_scontri);
 $squadra1 = $nome_posizione[$partita[0]];
 $squadra2 = $nome_posizione[$partita[1]];
-echo "<tr><td>".$nome_sqadra_memo[$squadra1]."-".$nome_sqadra_memo[$squadra2]."</td></tr>";
+echo "<tr><td>".$nome_sqadra_memo[$squadra1]."-".$nome_sqadra_memo[$squadra2]."</td><td>".$gol[$num_giornata_campionato][$squadra1]."-".$gol[$num_giornata_campionato][$squadra2]."</td></tr>";
 
 } # fine if ($campionato_in_corso == "SI")
 if ($inizio_giornata == "SI") {
@@ -108,7 +138,7 @@ if ($linea_file_scontri > $ultima_giornata) $ultima_giornata = $linea_file_scont
 if ($giornata_scritta <= $g_fine_camp) {
 if ($num_cella == 1) echo "<tr>";
 $giornata_in_corso = "SI";
-echo "<td><table align=\"center\" border=\"1\"><tr><td align=\"center\">Giornata $num_giornata_campionato</td></tr>";
+echo "<td><table align=\"center\" border=\"1\"><tr><td align=\"center\" colspan=2>Giornata $num_giornata_campionato</td></tr>";
 } # fine if ($giornata_scritta < $g_fine_camp)
 } # fine if ($inizio_giornata == "SI")
 if ($linea_file_scontri == "<giornata>") $inizio_giornata = "SI";
