@@ -20,10 +20,25 @@
 ##################################################################################
 
 
+# nel caso fosse settato register_globals = Off
+reset($_POST);
+for($num1 = 0 ; $num1 < count($_POST); $num1++) {
+$var_POST = key($_POST);
+$$var_POST = $_POST[$var_POST];
+next($_POST);
+} # fine for $num1
+reset($_GET);
+for($num1 = 0 ; $num1 < count($_GET); $num1++) {
+$var_GET = key($_GET);
+$$var_GET = $_GET[$var_GET];
+next($_GET);
+} # fine for $num1
+
+
 # Posizione delle cartelle "dati" e "scontri" rispetto alla cartella di fantacalciobazar. 
 # Cambiare SOLO SE queste cartelle non si trovano nella stessa cartella degli alti file 
 # di fantacalciobazar! Non mettere lo slash alla fine. La cartella "voti"  dove vengono 
-# posizionati i file votiXX.txt, di default la stessa "dati".
+# posizionati i file votiXX.txt e calciatori.txt, di default la stessa "dati".
 $percorso_cartella_dati = "./dati";
 $percorso_cartella_scontri = "./scontri";
 $percorso_cartella_voti = $percorso_cartella_dati;
@@ -42,15 +57,14 @@ $pass_admin_errata = "NO";
 } # fine if ($nome_utente == "admin")
 else {
 if (!$pass[$nome_utente]) {
-if ($parla != "NO") echo "Nome utente o password errati.<br>";
 $pass_errata = "SI";
 } # fine if (!$pass[$nome_utente])
 if ($pass[$nome_utente] == "nopasswordinserita") { $password = ""; }
 else { $password = $pass[$nome_utente]; }
 if ($pass_fornita != $password) {
-if ($parla != "NO") echo "Nome utente o password errati.<br>";
 $pass_errata = "SI";
 } # fine if ($pass_fornita != $password)
+if ($parla != "NO" and $pass_errata == "SI") echo "Nome utente o password errati.<br>";
 } # fine else if ($nome_utente == "admin")
 
 ?>
