@@ -2,8 +2,9 @@
 
 
 # 1) Giocatori e loro password (non utilizzare il nome admin). Inserire il nome
-# dei partecipanti tra le virgolette. Aggiungere o togliere linee per 
-# aggiungere o togliere giocatori. nopasswordinserita per password in bianco.
+# dei partecipanti tra le virgolette (senza spazi o caratteri strani). Aggiungere o 
+# togliere linee per  aggiungere o togliere giocatori. nopasswordinserita per 
+# password in bianco. GIOCATORE  diverso da giocatore (le maiuscole contano!).
 $pass["giocatore1"] = "nopasswordinserita";
 $pass["giocatore2"] = "nopasswordinserita";
 $pass["giocatore3"] = "nopasswordinserita";
@@ -13,8 +14,9 @@ $pass["giocatore6"] = "nopasswordinserita";
 $pass["giocatore7"] = "nopasswordinserita";
 $pass["giocatore8"] = "nopasswordinserita";
 
-# 2) Password dell'amministratore
+# 2) Password dell'amministratore e il nome con cui viene visto nei messaggi
 $passadmin = "nopasswordinserita";
+$nome_admin_in_messaggi = "Presidente";
 
 # 3) Soldi iniziali di ogni giocatore
 $soldi_iniziali = 250;
@@ -28,11 +30,19 @@ $aspetta_giorni = "04";
 $aspetta_ore = "00";
 $aspetta_minuti = "00";
 
-# 6) Gli schemi di gioco utilizzabili
-$schemi = array("1433","1442","1343","1352","1532","1541","1631");
+# 6) Gli schemi di gioco utilizzabili. Gli schemi a 5 numeri servono solo se si
+# usano i fantasisti. Si possono aggiungere o togliere schemi.
+$schemi = array("1433","1442","1343","1352","1532","1541","1631","13313","14312","13412","15311");
 
-# 7) Numero di calciatori in panchina
-$max_in_panchina = 5;
+# 7) Numero di calciatori in panchina e quanti ne possono entrare. Si possono fare 
+# sostituzioni per ruolo (il calciatore entra se un'altro del suo ruolo non ha giocato) o 
+# per schema (il calciatore entra se entrando lo schema che si forma  tra quelli 
+# consentiti). Se sia per ruolo che per schema sono a SI si sostituisce prima per ruolo.
+$max_in_panchina = 7;
+$max_entrate_dalla_panchina = 3;
+$sostituisci_per_ruolo = "SI";			# impostare a "SI" o "NO" (le maiuscole contano!)
+$sostituisci_fantasisti_come_centrocampisti = "NO";	# impostare a "SI" o "NO", usato solo con sostituzioni per ruolo, massimo 1 fantasista
+$sostituisci_per_schema = "SI";			# impostare a "SI" o "NO"
 
 # 8) Numero minimo di calciatori che devono essere titolari in formazione per ottenere 
 # punti (sono compresi anche quelli che non giocano). Non impostare a pi di 11.
@@ -55,7 +65,10 @@ $num_colonna_ruolo_file_calciatori = 3;
 $simbolo_portiere_file_calciatori = "P";
 $simbolo_difensore_file_calciatori = "D";
 $simbolo_centrocampista_file_calciatori = "C";
+$simbolo_fantasista_file_calciatori = "F";
 $simbolo_attaccante_file_calciatori = "A";
+$considera_fantasisti_come = "F";	# impostare a "F" per usare i fantasisti, "C" per considerarli centrocampisti, "A" attaccanti
+$num_colonna_squadra_file_calciatori = 0;	# opzionale, non c' se impostato a 0
 
 # 12) Composizione del file con i voti di giornata (dati/votiXX.txt)
 $separatore_campi_file_voti = ",";
@@ -73,7 +86,7 @@ $seconda_parte_pos_file_voti = "";      # parte che segue il n di giornata
 $diff_num_giornata_file = 0;            # differenza tra il n della giornata del file e quello del torneo di fantacalciobazar
                                      
 # 14) Dove e se far vedere i risultati di giornata
-$mostra_giornate_in_login = "NO";	# impostare a "SI" o "NO"
+$mostra_giornate_in_login = "SI";	# impostare a "SI" o "NO"
 $mostra_giornate_in_mercato = "SI";	# impostare a "SI" o "NO"
 
 # 15) Lista dei campionati che verranno disputati. Tra le virgolette vi devono 
@@ -112,6 +125,10 @@ $punti_posizione[8] = 0;
 # per chiuso (nessuna operazione di mercato consentita)
 $stato_mercato = "A";
 
+# 19) Impostare a "NO" se si vuole che i giocatori non possano pi cambiare il nome
+# e l'indirizzo del sito della loro squadra
+$nome_squadra_cambiabile = "SI";		# impostare a "SI" o "NO"
+$indirizzo_sito_squadra_cambiabile = "SI"	# impostare a "SI" o "NO"
 
 
 ?>
\ No newline at end of file
