@@ -37,12 +37,13 @@ echo "</center>
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"submit\" name=\"tab_calciatori\" value=\"Guarda tutti\">
-i<select name=\"ruolo_guarda\">
-<option value=\"tutti\">calciatori</option>
-<option value=\"P\">portieri</option>
-<option value=\"D\">difensori</option>
-<option value=\"C\">centrocampisti</option>
-<option value=\"A\">attaccanti</option>
+<select name=\"ruolo_guarda\">
+<option value=\"tutti\">i calciatori</option>
+<option value=\"P\">i portieri</option>
+<option value=\"D\">i difensori</option>
+<option value=\"C\">i centrocampisti</option>";
+if ($considera_fantasisti_come != "P" and $considera_fantasisti_come != "D" and $considera_fantasisti_come != "C" and $considera_fantasisti_come != "A") echo "<option value=\"F\">i fantasisti</option>";
+echo "<option value=\"A\">gli attaccanti</option>
 </select>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</form></td>
 <td><form method=\"post\" action=\"squadra.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
@@ -136,6 +137,7 @@ $vecchio_proprietario = "";
 $nuovo_costo = "";
 
 $dati_calciatore = explode(",", $calciatori[$num1]);
+if (count($dati_calciatore) >= 6) {
 $numero = $dati_calciatore[0];
 $nome = $dati_calciatore[1];
 $ruolo = $dati_calciatore[2];
@@ -189,6 +191,7 @@ echo "<tr><td>$numero</td>
 <td>$tempo_restante</td>
 <td>$offri</td></tr>";
 } # fine else if ($sec_restanti < 0)
+} # fine if (count($dati_calciatore) >= 6)
 
 } # fine for $num1
 echo "$tab_comprati</table>";
@@ -230,12 +233,23 @@ $pulsanti = 0;
 } # fine if ($pulsanti == 5)
 } # fine for $num1
 echo "</form>
-<form method=\"post\" action=\"crea_giornata.php\">
+<form method=\"post\" action=\"./crea_giornata.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
 <input type=\"submit\" name=\"crea_giornata\" value=\"Crea la giornata $num1\">
-</form></center>";
+</form><br><br>
+<form method=\"post\" action=\"./crea_sondaggio.php\">
+<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
+<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
+<input type=\"submit\" name=\"vai\" value=\"Sondaggi-Votazioni\">
+</form>
+<form method=\"post\" action=\"./messaggi.php\">
+<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
+<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
+<input type=\"submit\" name=\"vai\" value=\"Messaggi\">
+</form>
+</center>";
 } # fine if ($pass_admin_errata == "NO")
 
 include("$percorso_cartella_dati/foot.php");
