@@ -22,21 +22,24 @@
 
 include("./controlla_pass.php");
 include("$percorso_cartella_dati/head.php");
-if ($pass_errata != "SI") {
+if ($pass_errata != "SI" or $pass_admin_errata == "NO") {
 
 
 if ($aggiungi_messaggio) {
 $nuovo_messaggio = togli_acapo($nuovo_messaggio);
 $nuovo_messaggio = stripslashes($nuovo_messaggio);
+$nuovo_messaggio = aggiusta_tag($nuovo_messaggio);
 $file_messaggi = fopen("$percorso_cartella_dati/messaggi.txt","a+");
+$nome_utente_mostra = $nome_utente;
+if ($pass_admin_errata == "NO") $nome_utente_mostra = $nome_admin_in_messaggi;
 flock($file_messaggi,2);
-fwrite($file_messaggi,$nome_utente."#@?".$nuovo_messaggio."
+fwrite($file_messaggi,$nome_utente_mostra."#@?".date("d/m H:i")."#@?".$nuovo_messaggio."
 ");
 flock($file_messaggi,3);
 fclose($file_messaggi);
 } # fine if ($aggiungi_messaggio)
 
-
+echo "<table width=\"100%\"><tr valign =\"top\"><td>";
 echo "
 <center><font size=+2>Messaggi</font></center>";
 
@@ -48,8 +51,9 @@ if ($num_iniziale < 0) $num_iniziale = 0;
 for ($num1 = $num_iniziale ; $num1 < $num_messaggi ; $num1++) {
 $messaggio = explode("#@?",$messaggi[$num1]);
 $nome = $messaggio[0];
-$messaggio = $messaggio[1];
-echo "<font color=\"red\">$nome</font>: $messaggio<br>";
+$data = $messaggio[1];
+$testo_messaggio = $messaggio[2];
+echo "<font color=\"red\">$nome</font> <font size=-2 color=\"blue\"><$data></font> : $testo_messaggio<br>";
 } # fine for $num1
 
 echo "<center>";
@@ -63,20 +67,48 @@ echo "<a href=\"messaggi.php?tutti_i_messaggi=SI&nome_utente=$nome_utente&pass_f
 } # fine else if ($tutti_i_messaggi == "SI")
 echo "</center>";
 
+if ($ricarica) $testo_vecchio = $nuovo_messaggio;
+
 echo "<table><tr>
 <form method=\"post\" action=\"messaggi.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
-<td><textarea name=\"nuovo_messaggio\" rows=4 cols=50 wrap=\"virtual\"></textarea></td>
-<td><input type=\"submit\" name=\"aggiungi_messaggio\" value=\"Aggiungi\"></td>
-</form>
-<form method=\"post\" action=\"messaggi.php\">
-<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
-<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
-<input type=\"hidden\" name=\"nome_squadra\" value=\"$nome_utente\">
-<td><input type=\"submit\" name=\"ricarica\" value=\"Ricarica\"></td>
+<td><textarea name=\"nuovo_messaggio\" rows=4 cols=50 wrap=\"virtual\">$testo_vecchio</textarea></td>
+<td><input type=\"submit\" name=\"aggiungi_messaggio\" value=\"Aggiungi\">
+<input type=\"submit\" name=\"ricarica\" value=\"Ricarica\"></td>
 </form></tr></table>";
 
+if (@is_file("$percorso_cartella_dati/sondaggio.php")) {
+include("$percorso_cartella_dati/sondaggio.php");
+echo "</td><td width=\"100\"><br><font size=-1>";
+if ($voti_consentiti == 0) {
+echo "<center><b>Sondaggio ";
+$o = "o";
+} # fine if ($voti_consentiti == 0)
+else {
+echo "<center><b>Votazione ";
+$o = "a";
+} # fine else if ($voti_consentiti == 0)
+if ($voto_palese == "SI") echo "palese</b></center></font><br>";
+else echo "anonim$o</b></center></font><br>";
+if ($voti_consentiti > 1) echo "<center><font size=-2>$voti_consentiti voti consentiti</font></center><br>";
+echo "<font size=-2><font color=\"red\">$domanda</font><br>
+<form method=\"post\" action=\"./vota_sondaggio.php\">";
+$num_opzioni = count($opzioni);
+for ($num1 = 0 ; $num1 < $num_opzioni; $num1++) {
+$opzione = $num1+1;
+echo "<input type=\"radio\" name=\"voto\" value=\"$opzione\">".$opzioni[$num1]."<br>";
+} # fine for $num1
+echo "<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
+<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
+<div align=\"center\"><input type=\"submit\" name=\"vota\" value=\"vota\"></div>
+</form></font><center>
+<a href=\"./vota_sondaggio.php?nome_utente=$nome_utente&pass_fornita=$pass_fornita\">risultati</a>
+</center>";
+} # fine if (@is_file("$percorso_cartella_dati/sondaggio.php"))
+
+echo "</td></tr></table>";
+
 echo "<center><form method=\"post\" action=\"mercato.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
@@ -86,7 +118,7 @@ echo "<center><form method=\"post\" action=\"mercato.php\">
 
 
 
-} # fine if ($pass_errata != "SI")
+} # fine if ($pass_errata != "SI" or $pass_admin_errata == "NO")
 
 include("$percorso_cartella_dati/foot.php");
 ?>
