@@ -95,7 +95,7 @@ echo"<tr><td>$numero</td>
 
 if ($trovato != "SI") {
 $nuova_offerta = "SI";
-$calciatori = file("$percorso_cartella_dati/calciatori.txt");
+$calciatori = file("$percorso_cartella_voti/calciatori.txt");
 $num_calciatori = count($calciatori);
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
 $dati_calciatore = explode($separatore_campi_file_calciatori, $calciatori[$num1]);
@@ -106,12 +106,15 @@ $trovato = "SI";
 $nome = $dati_calciatore[($num_colonna_nome_file_calciatori-1)];
 $nome = togli_acapo($nome);
 $nome = ereg_replace("\"","",$nome);
-$ruolo = $dati_calciatore[($num_colonna_ruolo_file_calciatori-1)];
-$ruolo = togli_acapo($ruolo);
-if ($ruolo == $simbolo_portiere_file_calciatori) $ruolo = "P";
-if ($ruolo == $simbolo_difensore_file_calciatori) $ruolo = "D";
-if ($ruolo == $simbolo_centrocampista_file_calciatori) $ruolo = "C";
-if ($ruolo == $simbolo_attaccante_file_calciatori) $ruolo = "A";
+$s_ruolo = $dati_calciatore[($num_colonna_ruolo_file_calciatori-1)];
+$s_ruolo = togli_acapo($s_ruolo);
+$ruolo = $s_ruolo;
+if ($considera_fantasisti_come != "P" and $considera_fantasisti_come != "D" and $considera_fantasisti_come != "C" and $considera_fantasisti_come != "A") $considera_fantasisti_come = "F";
+if ($s_ruolo == $simbolo_fantasista_file_calciatori) $ruolo = $considera_fantasisti_come;
+if ($s_ruolo == $simbolo_portiere_file_calciatori) $ruolo = "P";
+if ($s_ruolo == $simbolo_difensore_file_calciatori) $ruolo = "D";
+if ($s_ruolo == $simbolo_centrocampista_file_calciatori) $ruolo = "C";
+if ($s_ruolo == $simbolo_attaccante_file_calciatori) $ruolo = "A";
 echo"<tr><td>$numero</td>
 <td>$nome</td>
 <td>$ruolo</td>
