@@ -298,7 +298,7 @@ if ($soldi_offerti != 0) $lista_off .= " + $soldi_offerti Euro";
 $nuovo_messaggio = "$nome_utente ha accettato lo scambio proposto da $utente_offerente per $lista_ric in cambio di $lista_off";
 $file_messaggi = fopen("$percorso_cartella_dati/messaggi.txt","a+");
 flock($file_messaggi,2);
-fwrite($file_messaggi,"Radio mercato#@?".$nuovo_messaggio."
+fwrite($file_messaggi,"Radio mercato#@?".date("d/m H:i")."#@?".$nuovo_messaggio."
 ");
 flock($file_messaggi,3);
 fclose($file_messaggi);
