@@ -27,12 +27,14 @@ $lista_titolari = "";
 $lista_titolari_P = "";
 $lista_titolari_D = "";
 $lista_titolari_C = "";
+$lista_titolari_F = "";
 $lista_titolari_A = "";
 $lista_panchinari = "";
 $num_titolari = 0;
 $num_titolari_P = 0;
 $num_titolari_D = 0;
 $num_titolari_C = 0;
+$num_titolari_F = 0;
 $num_titolari_A = 0;
 $num_panchinari = 0;
 $num_in_panchina_usati = "";
@@ -88,9 +90,10 @@ $lista_panchinari .= "$numero,";
 } # fine if ($num_in_panchina_usati[$num1])
 } # fine for $num1
 
-$lista_titolari = $lista_titolari_P.$lista_titolari_D.$lista_titolari_C.$lista_titolari_A;
+$lista_titolari = $lista_titolari_P.$lista_titolari_D.$lista_titolari_C.$lista_titolari_F.$lista_titolari_A;
 
 $schema = $num_titolari_P.$num_titolari_D.$num_titolari_C.$num_titolari_A;
+if ($num_titolari_F != 0) $schema = $num_titolari_P.$num_titolari_D.$num_titolari_C.$num_titolari_F.$num_titolari_A;
 $schema_trovato = "NO";
 if ($num_titolari > 11) {
 $inserire = "NO";
@@ -114,21 +117,34 @@ if ($num_titolari < 11) {
 $max_num_cons_P = 0;
 $max_num_cons_D = 0;
 $max_num_cons_C = 0;
+$max_num_cons_F = 0;
 $max_num_cons_A = 0;
 $num_schemi = count($schemi);
 for ($num1 = 0 ; $num1 < $num_schemi ; $num1++) {
+if (strlen($schemi[$num1]) == 4) {
 $num_cons_P = substr($schemi[$num1],0,1);
 $num_cons_D = substr($schemi[$num1],1,1);
 $num_cons_C = substr($schemi[$num1],2,1);
+$num_cons_F = 0;
 $num_cons_A = substr($schemi[$num1],3,1);
+} # fine if (strlen($schemi[$num1]) == 4)
+if (strlen($schemi[$num1]) == 5) {
+$num_cons_P = substr($schemi[$num1],0,1);
+$num_cons_D = substr($schemi[$num1],1,1);
+$num_cons_C = substr($schemi[$num1],2,1);
+$num_cons_F = substr($schemi[$num1],3,1);
+$num_cons_A = substr($schemi[$num1],4,1);
+} # fine if (strlen($schemi[$num1]) == 5)
 if ($num_cons_P > $max_num_cons_P) { $max_num_cons_P = $num_cons_P; }
 if ($num_cons_D > $max_num_cons_D) { $max_num_cons_D = $num_cons_D; }
 if ($num_cons_C > $max_num_cons_C) { $max_num_cons_C = $num_cons_C; }
+if ($num_cons_F > $max_num_cons_F) { $max_num_cons_F = $num_cons_F; }
 if ($num_cons_A > $max_num_cons_A) { $max_num_cons_A = $num_cons_A; }
 } # fine for $num1
 if ($num_titolari_P > $max_num_cons_P) { $inserire = "NO"; $frase .= "Troppi portieri!<br>"; }
 if ($num_titolari_D > $max_num_cons_D) { $inserire = "NO"; $frase .= "Troppi difensori!<br>"; }
 if ($num_titolari_C > $max_num_cons_C) { $inserire = "NO"; $frase .= "Troppi centrocampisti!<br>"; }
+if ($num_titolari_F > $max_num_cons_F) { $inserire = "NO"; $frase .= "Troppi fantasisti!<br>"; }
 if ($num_titolari_A > $max_num_cons_A) { $inserire = "NO"; $frase .= "Troppi attaccanti!<br>"; }
 } # fine if ($num_titolari < 11)
 
