@@ -28,7 +28,9 @@ if ($pass_errata != "SI") {
 
 if ($sfondo_tab == "") $sfondo_tab = "#b9ccd4";
 
-if ($cambia_soprannome) {
+if ($cambia_soprannome and $nome_squadra_cambiabile == "SI") {
+$nuovo_soprannome = htmlentities($nuovo_soprannome);
+$nuovo_soprannome = strip_tags($nuovo_soprannome);
 $num_giocatori=count($pass);
 reset($pass);
 for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
@@ -46,29 +48,40 @@ $filesquadra = fopen("$percorso_cartella_dati/squadra_$nome_utente","w+");
 flock($filesquadra,2);
 $num_linee = count($linee);
 if ($num_linee < 4) { $num_linee = 4; }
-if ($linee[0] == "") {
-$linee[0] = "
-";
-} # fine if ($linee[0] = "")
-if ($linee[1] == "") {
-$linee[1] = "
-";
-} # fine if ($linee[1] = "")
-if ($linee[2] == "") {
-$linee[2] = "
-";
-} # fine if ($linee[2] = "")
 $linee[3] = $nuovo_soprannome;
 rewind($filesquadra);
 for ($num1 = 0 ; $num1 < $num_linee ; $num1++) {
-fwrite($filesquadra,$linee[$num1]);
+fwrite($filesquadra,togli_acapo($linee[$num1])."
+");
 } # fine for $num1
 flock($filesquadra,3);
 flock($lock,3);
 fclose($filesquadra);
 fclose($lock);
 } # fine if (strlen($nuovo_soprannome) <= 20 and...)
-} # fine if ($cambia_soprannome)
+} # fine if ($cambia_soprannome and $nome_squadra_cambiabile == "SI")
+
+if ($cambia_homepage and $indirizzo_sito_squadra_cambiabile == "SI") {
+if ($inserire_url != "NO") {
+$lock = fopen("$percorso_cartella_dati/squadra_$nome_utente.lock","w+");
+flock($lock,2);
+$linee = @file("$percorso_cartella_dati/squadra_$nome_utente");
+$filesquadra = fopen("$percorso_cartella_dati/squadra_$nome_utente","w+");
+flock($filesquadra,2);
+$num_linee = count($linee);
+if ($num_linee < 5) { $num_linee = 5; }
+$linee[4] = $nuova_home_page;
+rewind($filesquadra);
+for ($num1 = 0 ; $num1 < $num_linee ; $num1++) {
+fwrite($filesquadra,togli_acapo($linee[$num1])."
+");
+} # fine for $num1
+flock($filesquadra,3);
+flock($lock,3);
+fclose($filesquadra);
+fclose($lock);
+} # fine if (strlen($nuovo_soprannome) <= 20 and...)
+} # fine if ($cambia_homepage and $indirizzo_sito_squadra_cambiabile == "SI")
 
 
 
@@ -94,6 +107,7 @@ $linea_offerto = "";
 $linea_comprato_P = "";
 $linea_comprato_D = "";
 $linea_comprato_C = "";
+$linea_comprato_F = "";
 $linea_comprato_A = "";
 $tab_comprati = "";
 $tab_offerte = "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"$sfondo_tab\">
@@ -187,6 +201,7 @@ $num_titolari = count($titolari);
 $tab_titolari_P = "";
 $tab_titolari_D = "";
 $tab_titolari_C = "";
+$tab_titolari_F = "";
 $tab_titolari_A = "";
 $inserito = "";
 $num_pos = 1;
@@ -213,6 +228,13 @@ $num_pos++;
 $tab_titolari_C .= $linea_comprato_C[$numero_titolare];
 $inserito[$numero_titolare] = "SI";
 } # fine if ($linea_comprato_C[$numero_titolare])
+if ($linea_comprato_F[$numero_titolare]) {
+$linea_comprato_F[$numero_titolare] = ereg_replace("value=\"titolare\"","value=\"titolare\" checked",$linea_comprato_F[$numero_titolare]);
+$linea_comprato_F[$numero_titolare] = ereg_replace("<tr><td>&nbsp;</td>","<tr><td>$num_pos</td>",$linea_comprato_F[$numero_titolare]);
+$num_pos++;
+$tab_titolari_F .= $linea_comprato_F[$numero_titolare];
+$inserito[$numero_titolare] = "SI";
+} # fine if ($linea_comprato_F[$numero_titolare])
 if ($linea_comprato_A[$numero_titolare]) {
 $linea_comprato_A[$numero_titolare] = ereg_replace("value=\"titolare\"","value=\"titolare\" checked",$linea_comprato_A[$numero_titolare]);
 $linea_comprato_A[$numero_titolare] = ereg_replace("<tr><td>&nbsp;</td>","<tr><td>$num_pos</td>",$linea_comprato_A[$numero_titolare]);
@@ -221,7 +243,7 @@ $tab_titolari_A .= $linea_comprato_A[$numero_titolare];
 $inserito[$numero_titolare] = "SI";
 } # fine if ($linea_comprato_A[$numero_titolare])
 } # fine for $num2
-echo $tab_titolari_P.$tab_titolari_D.$tab_titolari_C.$tab_titolari_A;
+echo $tab_titolari_P.$tab_titolari_D.$tab_titolari_C.$tab_titolari_F.$tab_titolari_A;
 
 # Tabella dei panchinari
 echo "<tr><td align=\"center\" colspan=\"$colspan\">In panchina</td></tr>";
@@ -230,6 +252,7 @@ $num_panchinari = count($panchinari);
 $tab_panchinari_P = "";
 $tab_panchinari_D = "";
 $tab_panchinari_C = "";
+$tab_panchinari_F = "";
 $tab_panchinari_A = "";
 $tab_panchinari = "";
 for ($num2 = 0 ; $num2 < $num_panchinari ; $num2++) {
@@ -259,6 +282,14 @@ $num_pos++;
 $tab_panchinari .= $linea_comprato_C[$numero_panchinaro];
 $inserito[$numero_panchinaro] = "SI";
 } # fine if ($linea_comprato_C[$numero_panchinaro])
+if ($linea_comprato_F[$numero_panchinaro]) {
+$linea_comprato_F[$numero_panchinaro] = ereg_replace("value=\"panchinaro\"","value=\"panchinaro\" checked",$linea_comprato_F[$numero_panchinaro]);
+$linea_comprato_F[$numero_panchinaro] = ereg_replace("option value=\"$num_in_panchina\"","option value=\"$num_in_panchina\" selected",$linea_comprato_F[$numero_panchinaro]);
+$linea_comprato_F[$numero_panchinaro] = ereg_replace("<tr><td>&nbsp;</td>","<tr><td>$num_pos</td>",$linea_comprato_F[$numero_panchinaro]);
+$num_pos++;
+$tab_panchinari .= $linea_comprato_F[$numero_panchinaro];
+$inserito[$numero_panchinaro] = "SI";
+} # fine if ($linea_comprato_F[$numero_panchinaro])
 if ($linea_comprato_A[$numero_panchinaro]) {
 $linea_comprato_A[$numero_panchinaro] = ereg_replace("value=\"panchinaro\"","value=\"panchinaro\" checked",$linea_comprato_A[$numero_panchinaro]);
 $linea_comprato_A[$numero_panchinaro] = ereg_replace("option value=\"$num_in_panchina\"","option value=\"$num_in_panchina\" selected",$linea_comprato_A[$numero_panchinaro]);
@@ -276,6 +307,7 @@ echo "<tr><td align=\"center\" colspan=\"$colspan\">Fuori rosa</td></tr>";
 $tab_fuori_P = "";
 $tab_fuori_D = "";
 $tab_fuori_C = "";
+$tab_fuori_F = "";
 $tab_fuori_A = "";
 $num_calciatori = count($lista_calciatori);
 for ($num2 = 0 ; $num2 < $num_calciatori ; $num2++) {
@@ -296,6 +328,11 @@ $linea_comprato_C[$numero_fuori] = ereg_replace("value=\"fuori\"","value=\"fuori
 $tab_fuori_C .= $linea_comprato_C[$numero_fuori];
 $inserito[$numero_fuori] = "SI";
 } # fine if ($linea_comprato_C[$numero_fuori])
+if ($linea_comprato_F[$numero_fuori]) {
+$linea_comprato_F[$numero_fuori] = ereg_replace("value=\"fuori\"","value=\"fuori\" checked",$linea_comprato_F[$numero_fuori]);
+$tab_fuori_F .= $linea_comprato_F[$numero_fuori];
+$inserito[$numero_fuori] = "SI";
+} # fine if ($linea_comprato_F[$numero_fuori])
 if ($linea_comprato_A[$numero_fuori]) {
 $linea_comprato_A[$numero_fuori] = ereg_replace("value=\"fuori\"","value=\"fuori\" checked",$linea_comprato_A[$numero_fuori]);
 $tab_fuori_A .= $linea_comprato_A[$numero_fuori];
@@ -303,9 +340,17 @@ $inserito[$numero_fuori] = "SI";
 } # fine if ($linea_comprato_A[$numero_fuori])
 } # fine if ($inserito[$num_fuori] != "SI")
 } # fine for $num2
-echo $tab_fuori_P.$tab_fuori_D.$tab_fuori_C.$tab_fuori_A;
+echo $tab_fuori_P.$tab_fuori_D.$tab_fuori_C.$tab_fuori_F.$tab_fuori_A;
 
 echo "</table>";
+
+$num_calciatori_comprabili = $max_calciatori - $num_calciatori_posseduti;
+$dati_giocatore = @file("$percorso_cartella_dati/squadra_$giocatore");
+$surplus = $dati_giocatore[0];
+$home_page_squadra = togli_acapo($dati_giocatore[4]);
+if (!$home_page_squadra) $home_page_squadra_vedi = "http://";
+$soldi_spendibili = $soldi_iniziali + $surplus - $soldi_spesi;
+
 if ($giocatore == $nome_utente) {
 for ($num2 = "01" ; $num2 < 100 ; $num2++) {
 if (strlen($num2) == 1) $num2 = "0".$num2;
@@ -316,22 +361,39 @@ echo "<center><br>
 <input type=\"submit\" name=\"cambia_formazione\" value=\"Cambia la formazione per la giornata $num2\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
-</center></form>
-<form method=\"post\" action=\"squadra.php\">
+</center></form>";
+if ($nome_squadra_cambiabile == "SI") {
+echo "<form method=\"post\" action=\"squadra.php\">
 <input type=\"submit\" name=\"cambia_soprannome\" value=\"Cambia il nome\">
  della squadra in <input type=\"text\" name=\"nuovo_soprannome\" size=\"20\" maxlength=\"20\" value=\"$soprannome_squadra\">
 <input type=\"hidden\" name=\"nome_squadra\" value=\"$nome_squadra\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 </form>";
+} # fine if ($nome_squadra_cambiabile == "SI")
+if ($indirizzo_sito_squadra_cambiabile == "SI") {
+echo "<form method=\"post\" action=\"squadra.php\">
+<input type=\"submit\" name=\"cambia_homepage\" value=\"Cambia l'indirizzo\">
+ della pagina ufficiale in <input type=\"text\" name=\"nuova_home_page\" size=\"20\" maxlength=\"50\" value=\"$home_page_squadra_vedi\">
+<input type=\"hidden\" name=\"nome_squadra\" value=\"$nome_squadra\">
+<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
+<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
+</form>";
+} # fine if ($indirizzo_sito_squadra_cambiabile == "SI")
 } # fine if ($giocatore == $nome_utente)
 
-$num_calciatori_comprabili = $max_calciatori - $num_calciatori_posseduti;
-$surplus = @file("$percorso_cartella_dati/squadra_$giocatore");
-$surplus = $surplus[0];
-$soldi_spendibili = $soldi_iniziali + $surplus - $soldi_spesi;
-echo "Soldi ancora da spendere: <b>$soldi_spendibili</b> Fanta-Euro.<br>
-Numero di calciatori ancora comperabili: <b>$num_calciatori_comprabili</b>.<br>";
+echo "<table width =\"100%\"><tr><td align=\"left\">
+Soldi ancora da spendere: <b>$soldi_spendibili</b> Fanta-Euro.<br>
+Numero di calciatori ancora comperabili: <b>$num_calciatori_comprabili</b>.</td>";
+if (@is_file("$percorso_cartella_dati/$giocatore.jpg") or $home_page_squadra) {
+echo "<td align=\"left\">";
+if ($home_page_squadra) echo "<a href=\"$home_page_squadra\" target=\"_blank\">";
+if (@is_file("$percorso_cartella_dati/$giocatore.jpg")) echo "<img src=\"$percorso_cartella_dati/$giocatore.jpg\" alt=\"Pagina ufficiale di $giocatore\" border=\"0\">";
+else echo "Pagina ufficiale";
+if ($home_page_squadra) echo "</a>";
+echo "</td>";
+} # fine if (@is_file("$percorso_cartella_dati/$giocatore.jpg") or $home_page_squadra)
+echo "</tr></table>";
 
 echo "<center>Offerte in corso</center>";
 $tab_offerte .= "</table>";
