@@ -104,7 +104,7 @@ flock($lockutente,3);
 $nuovo_messaggio = "$nome_utente ha venduto $nome per $prezzo_vendita Fanta-Euro";
 $file_messaggi = fopen("$percorso_cartella_dati/messaggi.txt","a+");
 flock($file_messaggi,2);
-fwrite($file_messaggi,"Radio mercato#@?".$nuovo_messaggio."
+fwrite($file_messaggi,"Radio mercato#@?".date("d/m H:i")."#@?".$nuovo_messaggio."
 ");
 flock($file_messaggi,3);
 fclose($file_messaggi);
